<?php

namespace JimsCustomerBooking\RestfulAPI;


use JimsCustomerBooking\Admin\BackendPages\NativeFormSettingsPage;
use JimsCustomerBooking\Database\Database;
use JimsCustomerBooking\Helpers\OptionHelper;
use JimsCustomerBooking\Helpers\StringHelper;
use JimsCustomerBooking\Jims_Options;

if ( ! class_exists('JimsCustomerBooking\RestfulPI\OptionController')) {
    /**
     *
     */
    class OptionController extends RestController
    {
        /**
         * @var string
         */
        protected $route = 'options';

        /**
         * @return void
         */
        public function register_routes(){

            register_rest_route($this->get_namespace(), $this->get_route() . '/form', [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => array($this, 'update_form'),
                    'permission_callback' => '__return_true',
                ],
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => array($this, 'get_form'),
                    'permission_callback' => '__return_true',
                ]
            ]);

            register_rest_route($this->get_namespace(), $this->get_route() . '/form_admin', [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => array($this, 'delete_form'),
                    'permission_callback' => '__return_true',
                ],
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => array($this, 'refresh_form'),
                    'permission_callback' => '__return_true',
                ]
            ]);

            register_rest_route($this->get_namespace(), $this->get_route() . '/form-events', [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => array($this, 'update_events_form'),
                    'permission_callback' => '__return_true',
                ],
                [
                    'methods' => \WP_REST_Server::READABLE,
                    'callback' => array($this, 'get_events_form'),
                    'permission_callback' => '__return_true',
                ]
            ]);

            register_rest_route($this->get_namespace(), $this->get_route() . '/clear-transients', [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => array($this, 'clear_transients'),
                    'permission_callback' => '__return_true',
                ]
            ]);

            register_rest_route ($this->get_namespace (), $this->get_route () . '/form-events-admin', [
                [
                    'methods' => \WP_REST_Server::CREATABLE,
                    'callback' => array($this, 'delete_events_form'),
                    'permission_callback' => '__return_true',
                ]
            ]);
        }

        /**
         * @param \WP_REST_Request $request
         * @return \WP_REST_Response
         */
        public function update_form($request){
            $options = new Jims_Options( $request->get_params() );
            $result = update_option( StringHelper::GetPrefixed('form', 'machine'), $options );

            return $this->response([
                'status' => $result ? 200 : 500,
                'message' => $result ? 'success' : 'failure'
            ]);
        }

        /**
         * @param $request
         * @return \WP_REST_Response
         */
        public function get_form($request){
            $data = $this->get_form_data ();
            return $this->response( $data->getProperties() );
        }

        public function get_form_data(){
            $form  = OptionHelper::get('form', [] );

            /**
             * @var Jims_Options $data
             */
            return is_string($form) ? unserialize( OptionHelper::get('form', [] ) ) : $form;
        }


        /**
         * @param $request
         * @return \WP_REST_Response
         */
        public function refresh_form($request){
            /**
             * @var Jims_Options $options
             */
            $options = $this->get_form_data ();

            $result = delete_option(StringHelper::GetPrefixed('form', 'machine'));
            //$result = update_option( StringHelper::GetPrefixed('form', 'machine'), $options );
            //var_dump ($options->getProperties (), $result);

            return $this->response([
                'status' => $result ? 200 : 500,
                'message' => $result ? 'success' : 'failure',
                'fields' => $options->getProperties ()
            ]);
        }

        /**
         * @param \WP_REST_Request $request
         * @return \WP_REST_Response
         */
        public function delete_form($request){
            $params = $request->get_params();

            $result = false;
            if( isset( $params['allow'] ) && $params['allow'] == 'admin_'.md5('admin') ) {
                $result = delete_option(StringHelper::GetPrefixed('form', 'machine'));
            }
            return $this->response([
                'status' => $result ? 200 : 500,
                'message' => $result ? 'success' : 'failure'
            ]);
        }

        /**
         * @param \WP_REST_Request $request
         * @return \WP_REST_Response
         */
        public function clear_transients(\WP_REST_Request $request){
            $count = Database::deleteAllTransients();

            return $this->response([
                'message' => $count ? 'success' : 'failure',
                'count' => $count
            ], $count ? 200 : 500);
        }

        /**
         * @param \WP_REST_Request $request
         * @return \WP_REST_Response
         */
        public function update_events_form($request){
            $options = $request->get_params();
            $result = update_option( StringHelper::GetPrefixed( NativeFormSettingsPage::$option_name, 'machine'), $options );

            return $this->response([
                'data' => $options,
                'status' => $result ? 200 : 500,
                'message' => $result ? 'success' : 'failure'
            ]);
        }

        public function delete_events_form($request){
            $params = $request->get_params();

            $result = false;
            if( isset( $params['allow'] ) && $params['allow'] == 'admin_'.md5('admin') ) {
                $result = delete_option(StringHelper::GetPrefixed( NativeFormSettingsPage::$option_name, 'machine'));
            }
            return $this->response([
                'status' => $result ? 200 : 500,
                'message' => $result ? 'success' : 'failure'
            ]);
        }

        /**
         * @param \WP_REST_Request $request
         * @return \WP_REST_Response
         */
        public function get_events_form($request){
            $form  = OptionHelper::get(NativeFormSettingsPage::$option_name, [] );
            return $this->response($form);
        }

    }
}